; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below.
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.

command.buffer.time = 2


;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;---------------------------------------------------------------------------
;-| Tag Commands DO NOT CHANGE
;--------------------------------------------------
[Command]
name = "COMBINATION"
command = ~D, DF, F, z+c
time = 10

[Command]
name = "COMBINATION"
command = ~D, DF, F, ~z+c
time = 10

[Command]
name = "CROSS"
command = ~D, DB, B, z+c
time = 10

[Command]
name = "CROSS"
command = ~D, DB, B, ~z+c
time = 10

[Command]
name = "ACTIVETAG"		;ORIGINAL COMMAND
command = z+c
time = 5

[Command]
name = "ACTIVETAG"		;ORIGINAL COMMAND
command = ~z+c
time = 5	

;[Command]
;name = "ACTIVETAG"		;ORIGINAL COMMAND
;command = x+a
;time = 5

;[Command]
;name = "ACTIVETAG"		;ORIGINAL COMMAND
;command = ~x+a
;time = 5	

;[Command]		;UNIQUE COMMAND
;name = "ACTIVETAG" 	;Uncomment these ACTIVETAG commands for a better
;command = s		;seamless change, default are the ones above.
;time = 1

[Command]
name = "TAG"		;CLASSIC COMMAND
command = z+c
time = 5

[Command]
name = "TAG"		;CLASSIC COMMAND
command = ~z+c
time = 5

[Command]			;CLASSIC COMMAND
name = "ASSIST"	
command = y+b	
time = 5		

[Command]			;CLASSIC COMMAND
name = "ASSIST"		
command = ~y+b
time = 5

;[Command]		;ARRANGED COMMAND	
;name = "ASSIST"	
;command = s	
;time = 1	

;[Command]		;ARRANGED COMMAND	
;name = "ASSIST"	
;command = ~s	
;time = 1		

;[Command]
;name = "SNAPBACK"		;ARRANGED COMMAND	
;command = ~D, DF, F, s
;time = 20

;[Command]
;name = "SNAPBACK"		;ARRANGED COMMAND	
;command = ~D, DF, F, ~s
;time = 20

[Command]
name = "SNAPBACK"		;ARRANGED COMMAND	
command = ~D, DF, F, x+a
time = 10

[Command]
name = "SNAPBACK"		;ARRANGED COMMAND	
command = ~D, DF, F, ~x+a
time = 10

;[Command]
;name = "SNAPBACK"		;ARRANGED COMMAND	
;command = ~D, DF, F, y+b
;time = 10

;[Command]
;name = "SNAPBACK"		;ARRANGED COMMAND	
;command = ~D, DF, F, ~y+b
;time = 10

[Command]
name = "CROSSOVERCOUNTER"
command = ~B, DB, D, z
time = 10

[Command]
name = "CROSSOVERCOUNTER"
command = ~B, DB, D, ~z
time = 20

[Command]
name = "CROSSOVERCOUNTER"
command = ~B, DB, D, c
time = 20

[Command]
name = "CROSSOVERCOUNTER"
command = ~B, DB, D, ~c
time = 20

;-| Counter/Recovery Roll |-----------------------------------------------------------
[Command]
name = "recoverf1"
command = ~B, DB, D, x
time = 20
[Command]
name = "recoverf2"
command = ~B, DB, D, y
time = 20
[Command]
name = "recoverf3"
command = ~B, DB, D, z
time = 20
[Command]
name = "recoverb1"
command = ~B, DB, D, a
time = 20
[Command]
name = "recoverb2"
command = ~B, DB, D, b
time = 20
[Command]
name = "recoverb3"
command = ~B, DB, D, c
time = 20

;---------------------------------------------------------------------------------------------
;Super Jump
[Command]
name = "Super_Jump"
command = $D, $U
Time=9

[Command]
name = "Super_Jump"
command = $D, $UF
Time=9

[Command]
name = "Super_Jump"
command = $D, $UB
Time=9

[Command]
name = "Super_Jump"
command = $DB, $U
Time=9

[Command]
name = "Super_Jump"
command = $DF, $U
Time=9

[Command]
name = "Super_Jump"
command = $DB, $UB
Time=9

[Command]
name = "Super_Jump"
command = $DF, $UF
Time=9

[Command]
name = "Super_Jump"
command = $DF, $UF
Time=9


;-| Super Motions |--------------------------------------------------------
;--------------------------------------------
;[command]
;name = "SGS1"
;command = ~x,x,F,a,z
;time = 24
;[command]
;name = "SGS1"
;command = ~x,x,/F,a,z
;time = 24
;[command]
;name = "SGS1"
;command = ~x,x,F,a,~z
;time = 24
;[command]
;name = "SGS1"
;command = ~x,x,/F,a,~z
;time = 24

;[command]
;name = "SGS2"
;command = ~x,x,F,a,y
;time = 24
;[command]
;name = "SGS2"
;command = ~x,x,/F,a,y
;time = 24
;[command]
;name = "SGS2"
;command = ~x,x,F,a,~y
;time = 24
;[command]
;name = "SGS2"
;command = ~x,x,/F,a,~y
;time = 24

;[command]
;name = "Black1"
;command = ~x,z,B,a,c
;time = 24

;[command]
;name = "Black1"
;command = ~x,z,B,a,~c
;time = 24

;[command]
;name = "Black1"
;command = ~x,z,/B,a,c
;time = 24

;[command]
;name = "Black1"
;command = ~x,z,/B,a,~c
;time = 24

;[command]
;name = "Black2"
;command = ~x,y,B,a,b
;time = 24

;[command]
;name = "Black2"
;command = ~x,y,B,a,~b
;time = 24

;[command]
;name = "Black2"
;command = ~x,y,/B,a,b
;time = 24

;[command]
;name = "Black2"
;command = ~x,y,/B,a,~b
;time = 24

;[command]
;name = "Magie1"
;command = ~c,x,D,a,z
;time = 24

;[command]
;name = "Magie1"
;command = ~c,x,/D,a,z
;time = 24

;[command]
;name = "Magie1"
;command = ~c,x,D,a,~z
;time = 24

;[command]
;name = "Magie1"
;command = ~c,x,/D,a,~z
;time = 24


;[command]
;name = "Magie2"
;command = ~c,x,D,a,y
;time = 24

;[command]
;name = "Magie2"
;command = ~c,x,/D,a,y
;time = 24

;[command]
;name = "Magie2"
;command = ~c,x,D,a,~y
;time = 24

;[command]
;name = "Magie2"
;command = ~c,x,/D,a,~y
;time = 24

;[command]
;name = "ES1"
;command = ~x,b,B,y,c
;time = 24

;[command]
;name = "ES1"
;command = ~x,b,/B,y,c
;time = 24

;[command]
;name = "ES1"
;command = ~x,b,B,y,~c
;time = 24

;[command]
;name = "ES1"
;command = ~x,b,/B,y,~c
;time = 24


;[command]
;name = "ES2"
;command = ~x,b,B,y,a
;time = 24

;[command]
;name = "ES2"
;command = ~x,b,/B,y,a
;time = 24

;[command]
;name = "ES2"
;command = ~x,b,B,y,~a
;time = 24

;[command]
;name = "ES2"
;command = ~x,b,/B,y,~a
;time = 24
;----------------------------
[command]
name = "3D_ab"
command = ~D, D, D, a+b
time = 24

[command]
name = "3D_bc"
command = ~D, D, D, b+c
time = 24

[command]
name = "3D_ac"
command = ~D, D, D, a+c
time = 24

[command]
name = "3D_ab"
command = ~D, D, D, ~a+b
time = 24

[command]
name = "3D_bc"
command = ~D, D, D, ~b+c
time = 24

[command]
name = "3D_ac"
command = ~D, D, D, ~a+c
time = 24

;----------------------------
[command]
name = "360_xy"
command = ~$F,D,B,/$U,x+y
time = 36

[command]
name = "360_xy"
command = ~$D,B,U,/$F,x+y
time = 36

[command]
name = "360_xy"
command = ~$B,U,F,/$D,x+y
time = 36

[command]
name = "360_xy"
command = ~$U,F,D,/$B,x+y
time = 36

[command]
name = "360_xy"
command = ~$B,D,F,/$U,x+y
time = 36

[command]
name = "360_xy"
command = ~$D,F,U,/$B,x+y
time = 36

[command]
name = "360_xy"
command = ~$F,U,B,/$D,x+y
time = 36

[command]
name = "360_xy"
command = ~$U,B,D,/$F,x+y
time = 36

[command]
name = "360_xy"
command = ~$F,D,B,/$U,~x+y
time = 36

[command]
name = "360_xy"
command = ~$D,B,U,/$F,~x+y
time = 36

[command]
name = "360_xy"
command = ~$B,U,F,/$D,~x+y
time = 36

[command]
name = "360_xy"
command = ~$U,F,D,/$B,~x+y
time = 36

[command]
name = "360_xy"
command = ~$B,D,F,/$U,~x+y
time = 36

[command]
name = "360_xy"
command = ~$D,F,U,/$B,~x+y
time = 36

[command]
name = "360_xy"
command = ~$F,U,B,/$D,~x+y
time = 36

[command]
name = "360_xy"
command = ~$U,B,D,/$F,~x+y
time = 36
;---------------------------------
[command]
name = "360_yz"
command = ~$F,D,B,/$U,y+z
time = 36

[command]
name = "360_yz"
command = ~$D,B,U,/$F,y+z
time = 36

[command]
name = "360_yz"
command = ~$B,U,F,/$D,y+z
time = 36

[command]
name = "360_yz"
command = ~$U,F,D,/$B,y+z
time = 36

[command]
name = "360_yz"
command = ~$B,D,F,/$U,y+z
time = 36

[command]
name = "360_yz"
command = ~$D,F,U,/$B,y+z
time = 36

[command]
name = "360_yz"
command = ~$F,U,B,/$D,y+z
time = 36

[command]
name = "360_yz"
command = ~$U,B,D,/$F,y+z
time = 36

[command]
name = "360_yz"
command = ~$F,D,B,/$U,~y+z
time = 36

[command]
name = "360_yz"
command = ~$D,B,U,/$F,~y+z
time = 36

[command]
name = "360_yz"
command = ~$B,U,F,/$D,~y+z
time = 36

[command]
name = "360_yz"
command = ~$U,F,D,/$B,~y+z
time = 36

[command]
name = "360_yz"
command = ~$B,D,F,/$U,~y+z
time = 36

[command]
name = "360_yz"
command = ~$D,F,U,/$B,~y+z
time = 36

[command]
name = "360_yz"
command = ~$F,U,B,/$D,~y+z
time = 36

[command]
name = "360_yz"
command = ~$U,B,D,/$F,~y+z
time = 36
;---------------------------------
[command]
name = "360_xz"
command = ~$F,D,B,/$U,x+z
time = 36

[command]
name = "360_xz"
command = ~$D,B,U,/$F,x+z
time = 36

[command]
name = "360_xz"
command = ~$B,U,F,/$D,x+z
time = 36

[command]
name = "360_xz"
command = ~$U,F,D,/$B,x+z
time = 36

[command]
name = "360_xz"
command = ~$B,D,F,/$U,x+z
time = 36

[command]
name = "360_xz"
command = ~$D,F,U,/$B,x+z
time = 36

[command]
name = "360_xz"
command = ~$F,U,B,/$D,x+z
time = 36

[command]
name = "360_xz"
command = ~$U,B,D,/$F,x+z
time = 36

[command]
name = "360_xz"
command = ~$F,D,B,/$U,~x+z
time = 36

[command]
name = "360_xz"
command = ~$D,B,U,/$F,~x+z
time = 36

[command]
name = "360_xz"
command = ~$B,U,F,/$D,~x+z
time = 36

[command]
name = "360_xz"
command = ~$U,F,D,/$B,~x+z
time = 36

[command]
name = "360_xz"
command = ~$B,D,F,/$U,~x+z
time = 36

[command]
name = "360_xz"
command = ~$D,F,U,/$B,~x+z
time = 36

[command]
name = "360_xz"
command = ~$F,U,B,/$D,~x+z
time = 36

[command]
name = "360_xz"
command = ~$U,B,D,/$F,~x+z
time = 36
;---------------------------------

[command]
name = "360_ab"
command = ~$F,D,B,/$U,a+b
time = 36

[command]
name = "360_ab"
command = ~$D,B,U,/$F,a+b
time = 36

[command]
name = "360_ab"
command = ~$B,U,F,/$D,a+b
time = 36

[command]
name = "360_ab"
command = ~$U,F,D,/$B,a+b
time = 36

[command]
name = "360_ab"
command = ~$B,D,F,/$U,a+b
time = 36

[command]
name = "360_ab"
command = ~$D,F,U,/$B,a+b
time = 36

[command]
name = "360_ab"
command = ~$F,U,B,/$D,a+b
time = 36

[command]
name = "360_ab"
command = ~$U,B,D,/$F,a+b
time = 36

[command]
name = "360_ab"
command = ~$F,D,B,/$U,~a+b
time = 36

[command]
name = "360_ab"
command = ~$D,B,U,/$F,~a+b
time = 36

[command]
name = "360_ab"
command = ~$B,U,F,/$D,~a+b
time = 36

[command]
name = "360_ab"
command = ~$U,F,D,/$B,~a+b
time = 36

[command]
name = "360_ab"
command = ~$B,D,F,/$U,~a+b
time = 36

[command]
name = "360_ab"
command = ~$D,F,U,/$B,~a+b
time = 36

[command]
name = "360_ab"
command = ~$F,U,B,/$D,~a+b
time = 36

[command]
name = "360_ab"
command = ~$U,B,D,/$F,~a+b
time = 36
;---------------------------------
[command]
name = "360_bc"
command = ~$F,D,B,/$U,b+c
time = 36

[command]
name = "360_bc"
command = ~$D,B,U,/$F,b+c
time = 36

[command]
name = "360_bc"
command = ~$B,U,F,/$D,b+c
time = 36

[command]
name = "360_bc"
command = ~$U,F,D,/$B,b+c
time = 36

[command]
name = "360_bc"
command = ~$B,D,F,/$U,b+c
time = 36

[command]
name = "360_bc"
command = ~$D,F,U,/$B,b+c
time = 36

[command]
name = "360_bc"
command = ~$F,U,B,/$D,b+c
time = 36

[command]
name = "360_bc"
command = ~$U,B,D,/$F,b+c
time = 36

[command]
name = "360_bc"
command = ~$F,D,B,/$U,~b+c
time = 36

[command]
name = "360_bc"
command = ~$D,B,U,/$F,~b+c
time = 36

[command]
name = "360_bc"
command = ~$B,U,F,/$D,~b+c
time = 36

[command]
name = "360_bc"
command = ~$U,F,D,/$B,~b+c
time = 36

[command]
name = "360_bc"
command = ~$B,D,F,/$U,~b+c
time = 36

[command]
name = "360_bc"
command = ~$D,F,U,/$B,~b+c
time = 36

[command]
name = "360_bc"
command = ~$F,U,B,/$D,~b+c
time = 36

[command]
name = "360_bc"
command = ~$U,B,D,/$F,~b+c
time = 36
;---------------------------------
[command]
name = "360_ac"
command = ~$F,D,B,/$U,a+c
time = 36

[command]
name = "360_ac"
command = ~$D,B,U,/$F,a+c
time = 36

[command]
name = "360_ac"
command = ~$B,U,F,/$D,a+c
time = 36

[command]
name = "360_ac"
command = ~$U,F,D,/$B,a+c
time = 36

[command]
name = "360_ac"
command = ~$B,D,F,/$U,a+c
time = 36

[command]
name = "360_ac"
command = ~$D,F,U,/$B,a+c
time = 36

[command]
name = "360_ac"
command = ~$F,U,B,/$D,a+c
time = 36

[command]
name = "360_ac"
command = ~$U,B,D,/$F,a+c
time = 36

[command]
name = "360_ac"
command = ~$F,D,B,/$U,~a+c
time = 36

[command]
name = "360_ac"
command = ~$D,B,U,/$F,~a+c
time = 36

[command]
name = "360_ac"
command = ~$B,U,F,/$D,~a+c
time = 36

[command]
name = "360_ac"
command = ~$U,F,D,/$B,~a+c
time = 36

[command]
name = "360_ac"
command = ~$B,D,F,/$U,~a+c
time = 36

[command]
name = "360_ac"
command = ~$D,F,U,/$B,~a+c
time = 36

[command]
name = "360_ac"
command = ~$F,U,B,/$D,~a+c
time = 36

[command]
name = "360_ac"
command = ~$U,B,D,/$F,~a+c
time = 36
;---------------------------------
[Command]
name = "DP_xy"
command = ~F, D, DF, x+y
time = 15
[Command]
name = "DP_yz"
command = ~F, D, DF, y+z
time = 15
[Command]
name = "DP_xz"
command = ~F, D, DF, x+z
time = 15

[Command]
name = "DP_xy"
command = ~F, D, DF, ~x+y
time = 15
[Command]
name = "DP_yz"
command = ~F, D, DF, ~y+z
time = 15
[Command]
name = "DP_xz"
command = ~F, D, DF, ~x+z
time = 15

;[Command]
;name = "DP_ab"
;command = ~F, D, DF, a+b
;time = 15
;[Command]
;name = "DP_bc"
;command = ~F, D, DF, b+c
;time = 15
;[Command]
;name = "DP_ac"
;command = ~F, D, DF, a+c
;time = 15

;[Command]
;name = "DP_ab"
;command = ~F, D, DF, ~a+b
;time = 15
;[Command]
;name = "DP_bc"
;command = ~F, D, DF, ~b+c
;time = 15
;[Command]
;name = "DP_ac"
;command = ~F, D, DF, ~a+c
;time = 15
;---------------------------------------------
[Command]
name = "QCF_xy"
command = ~D, DF, F, x+y
time = 10
[Command]
name = "QCF_xz"
command = ~D, DF, F, x+z
time = 10
[Command]
name = "QCF_yz"
command = ~D, DF, F, z+y
time = 10
[Command]
name = "QCF_xy"
command = ~D, DF, F, ~x+y
time = 10
[Command]
name = "QCF_xz"
command = ~D, DF, F, ~x+z
time = 10
[Command]
name = "QCF_yz"
command = ~D, DF, F, ~z+y
time = 10

[Command]
name = "QCB_xy"
command = ~D,DB,B,x+y
time = 10
[Command]
name = "QCB_yz"
command = ~D,DB,B,y+z
time = 10
[Command]
name = "QCB_xz"
command = ~D,DB,B,x+z
time = 10
[Command]
name = "QCB_xy"
command = ~D,DB,B,~x+y
time = 10
[Command]
name = "QCB_yz"
command = ~D,DB,B,~y+z
time = 10
[Command]
name = "QCB_xz"
command = ~D,DB,B,~x+z
time = 10

[Command]
name = "QCF_ab"
command = ~D, DF, F, a+b
time = 10
[Command]
name = "QCF_bc"
command = ~D, DF, F, b+c
time = 10
[Command]
name = "QCF_ac"
command = ~D, DF, F, a+c
time = 10
[Command]
name = "QCF_ab"
command = ~D, DF, F, ~a+b
time = 10
[Command]
name = "QCF_bc"
command = ~D, DF, F, ~b+c
time = 10
[Command]
name = "QCF_ac"
command = ~D, DF, F, ~a+c
time = 10

[Command]
name = "QCB_ab"
command = ~D, DB, B, a+b
time = 10
[Command]
name = "QCB_bc"
command = ~D, DB, B, b+c
time = 10
[Command]
name = "QCB_ac"
command = ~D, DB, B, a+c
time = 10
[Command]
name = "QCB_ab"
command = ~D, DB, B, ~a+b
time = 10
[Command]
name = "QCB_bc"
command = ~D, DB, B, ~b+c
time = 10
[Command]
name = "QCB_ac"
command = ~D, DB, B, ~a+c
time = 10

;-| Special Motions |------------------------------------------------------
[command]
name = "360_x"
command = ~$F,D,B,/$U,x
time = 36

[command]
name = "360_x"
command = ~$D,B,U,/$F,x
time = 36

[command]
name = "360_x"
command = ~$B,U,F,/$D,x
time = 36

[command]
name = "360_x"
command = ~$U,F,D,/$B,x
time = 36

[command]
name = "360_x"
command = ~$B,D,F,/$U,x
time = 36

[command]
name = "360_x"
command = ~$D,F,U,/$B,x
time = 36

[command]
name = "360_x"
command = ~$F,U,B,/$D,x
time = 36

[command]
name = "360_x"
command = ~$U,B,D,/$F,x
time = 36

[command]
name = "360_x"
command = ~$F,D,B,/$U,~x
time = 36

[command]
name = "360_x"
command = ~$D,B,U,/$F,~x
time = 36

[command]
name = "360_x"
command = ~$B,U,F,/$D,~x
time = 36

[command]
name = "360_x"
command = ~$U,F,D,/$B,~x
time = 36

[command]
name = "360_x"
command = ~$B,D,F,/$U,~x
time = 36

[command]
name = "360_x"
command = ~$D,F,U,/$B,~x
time = 36

[command]
name = "360_x"
command = ~$F,U,B,/$D,~x
time = 36

[command]
name = "360_x"
command = ~$U,B,D,/$F,~x
time = 36
;-----------------------------------
[command]
name = "360_y"
command = ~$F,D,B,/$U,y
time = 36

[command]
name = "360_y"
command = ~$D,B,U,/$F,y
time = 36

[command]
name = "360_y"
command = ~$B,U,F,/$D,y
time = 36

[command]
name = "360_y"
command = ~$U,F,D,/$B,y
time = 36

[command]
name = "360_y"
command = ~$B,D,F,/$U,y
time = 36

[command]
name = "360_y"
command = ~$D,F,U,/$B,y
time = 36

[command]
name = "360_y"
command = ~$F,U,B,/$D,y
time = 36

[command]
name = "360_y"
command = ~$U,B,D,/$F,y
time = 36

[command]
name = "360_y"
command = ~$F,D,B,/$U,~y
time = 36

[command]
name = "360_y"
command = ~$D,B,U,/$F,~y
time = 36

[command]
name = "360_y"
command = ~$B,U,F,/$D,~y
time = 36

[command]
name = "360_y"
command = ~$U,F,D,/$B,~y
time = 36

[command]
name = "360_y"
command = ~$B,D,F,/$U,~y
time = 36

[command]
name = "360_y"
command = ~$D,F,U,/$B,~y
time = 36

[command]
name = "360_y"
command = ~$F,U,B,/$D,~y
time = 36

[command]
name = "360_y"
command = ~$U,B,D,/$F,~y
time = 36
;-----------------------------------
[command]
name = "360_z"
command = ~$F,D,B,/$U,z
time = 36

[command]
name = "360_z"
command = ~$D,B,U,/$F,z
time = 36

[command]
name = "360_z"
command = ~$B,U,F,/$D,z
time = 36

[command]
name = "360_z"
command = ~$U,F,D,/$B,z
time = 36

[command]
name = "360_z"
command = ~$B,D,F,/$U,z
time = 36

[command]
name = "360_z"
command = ~$D,F,U,/$B,z
time = 36

[command]
name = "360_z"
command = ~$F,U,B,/$D,z
time = 36

[command]
name = "360_z"
command = ~$U,B,D,/$F,z
time = 36

[command]
name = "360_z"
command = ~$F,D,B,/$U,~z
time = 36

[command]
name = "360_z"
command = ~$D,B,U,/$F,~z
time = 36

[command]
name = "360_z"
command = ~$B,U,F,/$D,~z
time = 36

[command]
name = "360_z"
command = ~$U,F,D,/$B,~z
time = 36

[command]
name = "360_z"
command = ~$B,D,F,/$U,~z
time = 36

[command]
name = "360_z"
command = ~$D,F,U,/$B,~z
time = 36

[command]
name = "360_z"
command = ~$F,U,B,/$D,~z
time = 36

[command]
name = "360_z"
command = ~$U,B,D,/$F,~z
time = 36
;-----------------------------------

[command]
name = "360_a"
command = ~$F,D,B,/$U,a
time = 36

[command]
name = "360_a"
command = ~$D,B,U,/$F,a
time = 36

[command]
name = "360_a"
command = ~$B,U,F,/$D,a
time = 36

[command]
name = "360_a"
command = ~$U,F,D,/$B,a
time = 36

[command]
name = "360_a"
command = ~$B,D,F,/$U,a
time = 36

[command]
name = "360_a"
command = ~$D,F,U,/$B,a
time = 36

[command]
name = "360_a"
command = ~$F,U,B,/$D,a
time = 36

[command]
name = "360_a"
command = ~$U,B,D,/$F,a
time = 36

[command]
name = "360_a"
command = ~$F,D,B,/$U,~a
time = 36

[command]
name = "360_a"
command = ~$D,B,U,/$F,~a
time = 36

[command]
name = "360_a"
command = ~$B,U,F,/$D,~a
time = 36

[command]
name = "360_a"
command = ~$U,F,D,/$B,~a
time = 36

[command]
name = "360_a"
command = ~$B,D,F,/$U,~a
time = 36

[command]
name = "360_a"
command = ~$D,F,U,/$B,~a
time = 36

[command]
name = "360_a"
command = ~$F,U,B,/$D,~a
time = 36

[command]
name = "360_a"
command = ~$U,B,D,/$F,~a
time = 36
;-----------------------------------

[command]
name = "360_b"
command = ~$F,D,B,/$U,b
time = 36

[command]
name = "360_b"
command = ~$D,B,U,/$F,b
time = 36

[command]
name = "360_b"
command = ~$B,U,F,/$D,b
time = 36

[command]
name = "360_b"
command = ~$U,F,D,/$B,b
time = 36

[command]
name = "360_b"
command = ~$B,D,F,/$U,b
time = 36

[command]
name = "360_b"
command = ~$D,F,U,/$B,b
time = 36

[command]
name = "360_b"
command = ~$F,U,B,/$D,b
time = 36

[command]
name = "360_b"
command = ~$U,B,D,/$F,b
time = 36

[command]
name = "360_b"
command = ~$F,D,B,/$U,~b
time = 36

[command]
name = "360_b"
command = ~$D,B,U,/$F,~b
time = 36

[command]
name = "360_b"
command = ~$B,U,F,/$D,~b
time = 36

[command]
name = "360_b"
command = ~$U,F,D,/$B,~b
time = 36

[command]
name = "360_b"
command = ~$B,D,F,/$U,~b
time = 36

[command]
name = "360_b"
command = ~$D,F,U,/$B,~b
time = 36

[command]
name = "360_b"
command = ~$F,U,B,/$D,~b
time = 36

[command]
name = "360_b"
command = ~$U,B,D,/$F,~b
time = 36
;-----------------------------------

[command]
name = "360_c"
command = ~$F,D,B,/$U,c
time = 36

[command]
name = "360_c"
command = ~$D,B,U,/$F,c
time = 36

[command]
name = "360_c"
command = ~$B,U,F,/$D,c
time = 36

[command]
name = "360_c"
command = ~$U,F,D,/$B,c
time = 36

[command]
name = "360_c"
command = ~$B,D,F,/$U,c
time = 36

[command]
name = "360_c"
command = ~$D,F,U,/$B,c
time = 36

[command]
name = "360_c"
command = ~$F,U,B,/$D,c
time = 36

[command]
name = "360_c"
command = ~$U,B,D,/$F,c
time = 36

[command]
name = "360_c"
command = ~$F,D,B,/$U,~c
time = 36

[command]
name = "360_c"
command = ~$D,B,U,/$F,~c
time = 36

[command]
name = "360_c"
command = ~$B,U,F,/$D,~c
time = 36

[command]
name = "360_c"
command = ~$U,F,D,/$B,~c
time = 36

[command]
name = "360_c"
command = ~$B,D,F,/$U,~c
time = 36

[command]
name = "360_c"
command = ~$D,F,U,/$B,~c
time = 36

[command]
name = "360_c"
command = ~$F,U,B,/$D,~c
time = 36

[command]
name = "360_c"
command = ~$U,B,D,/$F,~c
time = 36
;-----------------------------------

[command]
name = "charge_x"
command = ~36$B, F, x
[command]
name = "charge_x"
command = ~36$B, F, ~x

[command]
name = "charge_y"
command = ~36$B, F, y
[command]
name = "charge_y"
command = ~36$B, F, ~y

[command]
name = "charge_z"
command = ~36$B, F, z
[command]
name = "charge_z"
command = ~36$B, F, ~z

[command]
name = "charge_a"
command = ~36$B, F, a
[command]
name = "charge_a"
command = ~36$B, F, ~a

[command]
name = "charge_b"
command = ~36$B, F, b
[command]
name = "charge_b"
command = ~36$B, F, ~b

[command]
name = "charge_c"
command = ~36$B, F, c
[command]
name = "charge_c"
command = ~36$B, F, ~c


[command]
name = "dcharge_x"
command = ~36$D, U, x
[command]
name = "dcharge_x"
command = ~36$D, U, ~x

[command]
name = "dcharge_y"
command = ~36$D, U, y
[command]
name = "dcharge_y"
command = ~36$D, U, ~y

[command]
name = "dcharge_z"
command = ~36$D, U, z
[command]
name = "dcharge_z"
command = ~36$D, U, ~z

[command]
name = "dcharge_a"
command = ~36$D, U, a
[command]
name = "dcharge_a"
command = ~36$D, U, ~a

[command]
name = "dcharge_b"
command = ~36$D, U, b
[command]
name = "dcharge_b"
command = ~36$D, U, ~b

[command]
name = "dcharge_c"
command = ~36$D, U, c
[command]
name = "dcharge_c"
command = ~36$D, U, ~c

[Command]
name = "DP_x"
command = ~F, D, DF, x
[Command]
name = "DP_y"
command = ~F, D, DF, y
[Command]
name = "DP_z"
command = ~F, D, DF, z
[Command]
name = "DP_x"
command = ~F, D, DF, ~x
[Command]
name = "DP_y"
command = ~F, D, DF, ~y
[Command]
name = "DP_z"
command = ~F, D, DF, ~z

[Command]
name = "RDP_x"
command = ~B, D, DB, x
[Command]
name = "RDP_y"
command = ~B, D, DB, y
[Command]
name = "RDP_z"
command = ~B, D, DB, z
[Command]
name = "RDP_x"
command = ~B, D, DB, ~x
[Command]
name = "RDP_y"
command = ~B, D, DB, ~y
[Command]
name = "RDP_z"
command = ~B, D, DB, ~z
;--------------------------
[Command]
name = "DP_a"
command = ~F, D, DF, a
[Command]
name = "DP_b"
command = ~F, D, DF, b
[Command]
name = "DP_c"
command = ~F, D, DF, c
[Command]
name = "DP_a"
command = ~F, D, DF, ~a
[Command]
name = "DP_b"
command = ~F, D, DF, ~b
[Command]
name = "DP_c"
command = ~F, D, DF, ~c

[Command]
name = "RDP_a"
command = ~B, D, DB, a
[Command]
name = "RDP_b"
command = ~B, D, DB, b
[Command]
name = "RDP_c"
command = ~B, D, DB, c
[Command]
name = "RDP_a"
command = ~B, D, DB, ~a
[Command]
name = "RDP_b"
command = ~B, D, DB, ~b
[Command]
name = "RDP_c"
command = ~B, D, DB, ~c
;-----------------------
[Command]
name = "HCF_x"
command = ~B, $D, F, x
time = 15
[Command]
name = "HCF_y"
command = ~B, $D, F, y
time = 15
[Command]
name = "HCF_z"
command = ~B, $D, F, z
time = 15
[Command]
name = "HCF_x"
command = ~B, $D, F, ~x
time = 15
[Command]
name = "HCF_y"
command = ~B, $D, F, ~y
time = 15
[Command]
name = "HCF_z"
command = ~B, $D, F, ~z
time = 15
;-----------------------
;[Command]
;name = "HCF_a"
;command = ~B, $D, F, a
;time = 15
;[Command]
;name = "HCF_b"
;command = ~B, $D, F, b
;time = 15
;[Command]
;name = "HCF_c"
;command = ~B, $D, F, c
;time = 15
;[Command]
;name = "HCF_a"
;command = ~B, $D, F, ~a
;time = 15
;[Command]
;name = "HCF_b"
;command = ~B, $D, F, ~b
;time = 15
;[Command]
;name = "HCF_c"
;command = ~B, $D, F, ~c
;time = 15
;-----------------------
;[Command]
;name = "HCB_x"
;command = ~F, $D, B, x
;time = 15
;[Command]
;name = "HCB_y"
;command = ~F, $D, B, y
;time = 15
;[Command]
;name = "HCB_z"
;command = ~F, $D, B, z
;time = 15
;[Command]
;name = "HCB_x"
;command = ~F, $D, B, ~x
;time = 15
;[Command]
;name = "HCB_y"
;command = ~F, $D, B, ~y
;time = 15
;[Command]
;name = "HCB_z"
;command = ~F, $D, B, ~z
;time = 15
;-----------------------
[Command]
name = "HCB_a"
command = ~F, $D, B, a
time = 15
[Command]
name = "HCB_b"
command = ~F, $D, B, b
time = 15
[Command]
name = "HCB_c"
command = ~F, $D, B, c
time = 15
[Command]
name = "HCB_a"
command = ~F, $D, B, ~a
time = 15
[Command]
name = "HCB_b"
command = ~F, $D, B, ~b
time = 15
[Command]
name = "HCB_c"
command = ~F, $D, B, ~c
time = 15

;-----------------------
[Command]
name = "QCF_x"
command = ~D, DF, F, x
[Command]
name = "QCF_y"
command = ~D, DF, F, y
[Command]
name = "QCF_z"
command = ~D, DF, F, z
[Command]
name = "QCF_x"
command = ~D, DF, F, ~x
[Command]
name = "QCF_y"
command = ~D, DF, F, ~y
[Command]
name = "QCF_z"
command = ~D, DF, F, ~z
;-----------------------
;[Command]
;name = "UQCF_x"
;command = ~U, UF, F, x
;[Command]
;name = "UQCF_y"
;command = ~U, UF, F, y
;[Command]
;name = "UQCF_z"
;command = ~U, UF, F, z
;[Command]
;name = "UQCF_x"
;command = ~U, UF, F, ~x
;[Command]
;name = "UQCF_y"
;command = ~U, UF, F, ~y
;[Command]
;name = "UQCF_z"
;command = ~U, UF, F, ~z
;-----------------------
[Command]
name = "QCF_a"
command = ~D, DF, F, a
[Command]
name = "QCF_b"
command = ~D, DF, F, b
[Command]
name = "QCF_c"
command = ~D, DF, F, c
[Command]
name = "QCF_a"
command = ~D, DF, F, ~a
[Command]
name = "QCF_b"
command = ~D, DF, F, ~b
[Command]
name = "QCF_c"
command = ~D, DF, F, ~c
;-----------------------
;[Command]
;name = "UQCF_a"
;command = ~U, UF, F, a
;[Command]
;name = "UQCF_b"
;command = ~U, UF, F, b
;[Command]
;name = "UQCF_c"
;command = ~U, UF, F, c
;[Command]
;name = "UQCF_a"
;command = ~U, UF, F, ~a
;[Command]
;name = "UQCF_b"
;command = ~U, UF, F, ~b
;[Command]
;name = "UQCF_c"
;command = ~U, UF, F, ~c
;-------------------------
[Command]
name = "QCB_x"
command = ~D, DB, B, x
[Command]
name = "QCB_y"
command = ~D, DB, B, y
[Command]
name = "QCB_z"
command = ~D, DB, B, z
[Command]
name = "QCB_x"
command = ~D, DB, B, ~x
[Command]
name = "QCB_y"
command = ~D, DB, B, ~y
[Command]
name = "QCB_z"
command = ~D, DB, B, ~z
;-------------------------
[Command]
name = "QCB_a"
command = ~D, DB, B, a
[Command]
name = "QCB_b"
command = ~D, DB, B, b
[Command]
name = "QCB_c"
command = ~D, DB, B, c
[Command]
name = "QCB_a"
command = ~D, DB, B, ~a
[Command]
name = "QCB_b"
command = ~D, DB, B, ~b
[Command]
name = "QCB_c"
command = ~D, DB, B, ~c
;---------------------
[Command]
name = "x4"
command = x, x, x, x
time=20
[Command]
name = "y4"
command = y, y, y, y
time=20
[Command]
name = "z4"
command = z, z, z, z
time=20
[Command]
name = "x4"
command = ~x, x, x, x
time=20
[Command]
name = "y4"
command = ~y, y, y, y
time=20
[Command]
name = "z4"
command = ~z, z, z, z
time=20
;--------------------
[Command]
name = "a4"
command = a, a, a, a
time=20
[Command]
name = "b4"
command = b, b, b, b
time=20
[Command]
name = "c4"
command = c, c, c, c
time=20
[Command]
name = "a4"
command = ~a, a, a, a
time=20
[Command]
name = "b4"
command = ~b, b, b, b
time=20
[Command]
name = "c4"
command = ~c, c, c, c
time=20

[Command]
name = "counter1"
command = ~B, DB, D, x
time = 20
[Command]
name = "counter1"
command = ~B, DB, D, ~x
time = 20
[Command]
name = "counter1"
command = ~B, DB, D, y
time = 20
[Command]
name = "counter1"
command = ~B, DB, D, ~y
time = 20
[Command]
name = "counter1"
command = ~B, DB, D, z
time = 20
[Command]
name = "counter1"
command = ~B, DB, D, ~z
time = 20

[Command]
name = "counter2"
command = ~B, DB, D, a
time = 20
[Command]
name = "counter2"
command = ~B, DB, D, b
time = 20
[Command]
name = "counter2"
command = ~B, DB, D, c
time = 20
[Command]
name = "counter2"
command = ~B, DB, D, ~a
time = 20
[Command]
name = "counter2"
command = ~B, DB, D, ~b
time = 20
[Command]
name = "counter2"
command = ~B, DB, D, ~c
time = 20

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

[Command]
name = "recovery";Required (do not remove)
command = a+b
time = 1
;-------------------------
[command]
name = "xy"
command = x+y
time = 1

[command]
name = "ab"
command = a+b
time = 1
;---------------------------
[command]
name = "2p"
command = x+y
time = 1

[command]
name = "2p"
command = y+z
time = 1

[command]
name = "2p"
command = x+z
time = 1

[command]
name = "2k"
command = a+b
time = 1

[command]
name = "2k"
command = b+c
time = 1

[command]
name = "2k"
command = a+c
time = 1

;-| Dir + Button |---------------------------------------------------------

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

[Command]
name = "holda"
command = /a
time = 1

[Command]
name = "holdb"
command = /b
time = 1

[Command]
name = "holdc"
command = /c
time = 1

[Command]
name = "holdx"
command = /x
time = 1

[Command]
name = "holdy"
command = /y
time = 1

[Command]
name = "holdz"
command = /z
time = 1

[Command]
name = "holdstart"
command = /s
time = 1

;-| Tap Dir |--------------------------------------------------------------
[Command]
name = "up";Required (do not remove)
command = $U
time = 1

[Command]
name = "down";Required (do not remove)
command = $D
time = 1

[Command]
name = "fwd";Required (do not remove)
command = F
time = 1

[Command]
name = "back";Required (do not remove)
command = B
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;---------------------------------------------------------------------------
;NEW -1 TAG STATES

;---------------------------------------------------------------------------
[State -1, Delayed Hyper Combo (TAG IN)] 		;Modify this
type = ChangeState
triggerall = roundstate = 2
triggerall = movetype != H
triggerall = alive
triggerall = sysvar(3) = 1				;Is tagged out
triggerall = playeridexist(sysvar(4))			;Partner exists
triggerall = playerid(sysvar(4)), sysvar(3) = [15,16]	;Partner in Hyper Attack and DHC is detectable
triggerall = stateno = 87000				;Was offstage
trigger1 = (Var(54) = 0 && (command = "DP_xy" || command = "DP_yz" || command = "DP_xz")) || (Var(54) = 1 && (command = "DP_xy"))
trigger1 = power >= 3000
trigger2 = (Var(54) = 0 && (command = "QCF_xy" || command = "QCF_yz" || command = "QCF_xz")) || (Var(54) = 1 && (command = "QCF_xy"))
trigger2 = power >= 1000
trigger3 = (Var(54) = 0 && (command = "QCF_ab" || command = "QCF_bc" || command = "QCF_ac")) || (Var(54) = 1 && (command = "QCF_ab"))
trigger3 = power >= 1000
value = 87050					;Add the commands to this state for DHC

[State -1, (TAG) CROSS OVER COUNTER]
type = ChangeState
triggerall = roundstate = 2
;triggerall = playeridexist(sysvar(4))			;Partner exists
trigger1 = command = "CROSSOVERCOUNTER"
trigger1 = power >= 1000
trigger1 = p2dist x > 0
trigger1 = statetype != A
trigger1 = stateno = 150
value = 85900		;Go to this tag state to add your counter attack

;----------------------------------------------------------------
;TEAM AERIAL COMBO (DISABLE THIS IF YOU WANT)
;----------------------------------------------------------------
[State -1, CROSS OVER COMBINATION]
type = ChangeState
triggerall = roundstate = 2
triggerall = statetype != A
triggerall = movetype != H
triggerall = (stateno != [87000,87999])
triggerall = power >= 1000
triggerall = command = "COMBINATION" 
triggerall = playeridexist(sysvar(4))
triggerall = sysvar(3) = 0 ;Currently Tagged In
trigger1 = ctrl
trigger2 = stateno = [200,499]
value = 87500			;Go to this tag state to include team hyper attack
ctrl = 0

;----------------------------------------------------------------
;VARIABLE CROSS(DISABLE THIS IF YOU WANT)
;----------------------------------------------------------------
[State -1, VARIABLE CROSS]
type = null ;ChangeState
triggerall = roundstate = 2
triggerall = statetype != A
triggerall = movetype != H
triggerall = (stateno != [87000,87999])
triggerall = power >= 2000
triggerall = command = "CROSS" 
triggerall = playeridexist(sysvar(4))
triggerall = playerid(sysvar(4)), sysvar(3) = 1
triggerall = playerid(sysvar(4)), stateno = 87000
triggerall = sysvar(3) = 0 ;Currently Tagged In
trigger1 = ctrl
trigger2 = stateno = [200,499]
value = 87400

;----------------------------------------------------------------
;TEAM AERIAL COMBO (DISABLE THIS IF YOU WANT)
;----------------------------------------------------------------
[State -1, (TAG) TEAM AERIAL COMBO]
type = ChangeState
triggerall = roundstate = 2
triggerall = playeridexist(sysvar(4))			;Partner exists
triggerall = playerid(sysvar(4)), sysvar(3) = 1
triggerall = playerid(sysvar(4)),stateno = 87000
triggerall = sysvar(3) = 0
trigger1 = command = "TAG" && (command = "holdup" || command = "holdfwd" || command = "holddown")
trigger1 = statetype = A
trigger1 = ctrl || (stateno = [600,699])
trigger1 = var(12) = 1	;Aerial Rave on
value = 87105
;ignorehitpause = 1

;----------------------------------------------------------------
;CLASSIC TAG OUT
;----------------------------------------------------------------
[State -1, TAG OUT]
type = ChangeState
triggerall = roundstate = 2
triggerall = (stateno != [87000,87999])
triggerall = playeridexist(sysvar(4))			;Partner exists
triggerall = sysvar(3) = 0 ;Currently Tagged In
triggerall = playerid(sysvar(4)), sysvar(3) = 1 ;Partner Var is Tagged Out
triggerall = playerid(floor(sysvar(4))), stateno = 87000 ;Partner Tagged Out
triggerall = command = "TAG" 
triggerall = statetype != A
trigger1 = ctrl
trigger2 = movetype = A
trigger2 = hitdefattr = SCA, NA
value = 87100

;----------------------------------------------------------------
;SNAPBACK (YOU CAN DISABLE THIS IF YOU WANT)
;----------------------------------------------------------------
[State -1, SNAPBACK]
type = ChangeState
triggerall = roundstate = 2
triggerall = playeridexist(sysvar(4))			;Partner exists
triggerall = statetype != A
triggerall = power >= 1000
triggerall = command = "SNAPBACK" 
triggerall = numenemy >= 2
triggerall = sysvar(3) = 0 ;Currently Tagged In
trigger1 = ctrl
trigger2 = stateno = [200,499]
value = 85950

;----------------------------------------------------------------
;ACTIVE SWITCH/COUNTER SWITCH (YOU CAN DISABLE THIS IF YOU WANT)
;----------------------------------------------------------------
[State -1, ACTIVE TAG/COUNTER TAG CALL]
type = null;VarSet
triggerall = roundstate = 2
triggerall = NumExplod(82329)
triggerall = alive
triggerall = playeridexist(sysvar(4)) 			;Partner exists
triggerall = (stateno != [87000,87999])			;Not in Tag States
triggerall = sysvar(3) != [5,10]
triggerall = command = "ACTIVETAG"
triggerall = playerid(sysvar(4)), sysvar(3) = 1 		;Partner var is tagged out
triggerall = playerid(sysvar(4)), stateno = 87000 	;Partner is tagged out
trigger1 = movetype = A ;|| ctrl
trigger1 = (stateno != [3000,3999]) && (stateno != [16000,17999])
trigger2 = movetype = H
trigger2 = (enemynear((numenemy=2) * ((enemynear,sysvar(3) = [1,2]) || (enemynear,sysvar(3) = [9,10]))), sysvar(3) != [5,19])
trigger2 = (enemynear((numenemy=2) * ((enemynear,sysvar(3) = [1,2]) || (enemynear,sysvar(3) = [9,10]))), movetype = A)
trigger2 = power >= 2000
sysvar(3) = ifelse(movetype = H, 10, 9)

[State -1, (TAG) COUNTER SWITCH EFFECT]
type = null;Explod
trigger1 = sysvar(3) = [9,10]
trigger1 = time = 1
anim = f88008 
pos = const(size.mid.pos.x),const(size.mid.pos.y)
postype = p1
bindtime = -1
removetime = -2
scale = .5,.5
sprpriority = 5
ownpal = 1

[State -1, (TAG) PalFX ACTIVE/COUNTER SWITCH]
type = null;PalFX
trigger1 = sysvar(3) = [9,10]
time = 24
add = -64,-64,64
sinadd = 24,24,24,4

[State -1, (TAG) PlaySnd ACTIVE/COUNTER SWITCH]
type = null;PlaySnd
trigger1 = sysvar(3) = [9,10]
value = F8600,0

[State -1, COUNTER TAG POWER ADD]
type = null;PowerAdd
trigger1 = power >= 2000
trigger1 = sysvar(3) = 10
trigger1 = movetype = H
value = -2000
;----------------------------------------------------------------
;END OF TAG COMMAND STATES
;----------------------------------------------------------------

;---------------------------------------------------------------------------
;Proto Excalibur
[State -1, Proto Excalibur]
type = ChangeState
value = 3900
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
;triggerall = !var(12) || var(12) = 2
triggerall = ((command = "DP_xy" || command = "DP_yz" || command = "DP_xz") && var(54)=0) || (command = "DP_xy" && var(54))
triggerall = power >= 3000
triggerall = statetype != A
triggerall = !NumHelper(89000) ;No cinematic level 3s during variable cross
triggerall = cond(playeridexist(sysvar(4)), !playerid(sysvar(4)), numhelper(89000), 1)
trigger1 = ctrl
trigger2 = stateno = [200,499]
trigger3 = stateno = [1000,1999]

;---------------------------------------------------------------------------
;Big Bang Blaster
[State -1, Big Bang Strike]
type = ChangeState
value = 3000
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
;triggerall = !var(12) || var(12) = 2
triggerall = ((command = "QCF_xy" || command = "QCF_yz" || command = "QCF_xz") && var(54)=0) || (command = "QCF_xy" && var(54))
triggerall = power >= 1000
trigger1 = ctrl
trigger2 = stateno = [200,699]
trigger3 = stateno = [1000,1999]

;---------------------------------------------------------------------------
;Proto Shield Barrage
[State -1, Shield Barrage]
type = ChangeState
value = 3100
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
;triggerall = !var(12) || var(12) = 2
triggerall = ((command = "QCF_ab" || command = "QCF_bc" || command = "QCF_ac") && var(54)=0) || (command = "QCF_ab" && var(54))
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = [200,699]
trigger3 = stateno = [1000,1999]

;---------------------------------------------------------------------------
;Proto Strike
[State -1, Proto Strike Fierce]
type = ChangeState
value = 1102
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = (command = "DP_z" && var(54)=0) || (command = "DP_y" && var(54))
trigger1 = ctrl
trigger2 = stateno = [200,699]

;---------------------------------------------------------------------------
;Proto Strike
[State -1, Proto Strike Strong]
type = ChangeState
value = 1101
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = (command = "DP_y" && var(54)=0)
trigger1 = ctrl
trigger2 = stateno = [200,699]

;---------------------------------------------------------------------------
;Proto Strike
[State -1, Proto Strike Jab]
type = ChangeState
value = 1100
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = command = "DP_x"
trigger1 = ctrl
trigger2 = stateno = [200,699]

;---------------------------------------------------------------------------
;Skull Barrier
[State -1, Skull Barrier]
type = ChangeState
value = 1500
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = ((command = "QCB_z" || command = "QCB_y" || command = "QCB_x") && var(54)=0) || ((command = "QCB_y" || command = "QCB_x") && var(54))
triggerall = !numhelper(1510)
triggerall = Statetype != A
trigger1 = ctrl
trigger2 = stateno = [200,499]

;---------------------------------------------------------------------------
;Proto Charge
[State -1, Proto Shield Fierce]
type = ChangeState
value = 1302
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = (command = "QCF_c" && var(54)=0) || (command = "QCF_b" && var(54))
triggerall = (!var(10) && statetype = A) || Statetype != A
trigger1 = ctrl
trigger2 = stateno = [200,699]

;---------------------------------------------------------------------------
;Proto Charge
[State -1, Proto Shield Strong]
type = ChangeState
value = 1301
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = (command = "QCF_b" && var(54)=0)
triggerall = (!var(10) && statetype = A) || Statetype != A
trigger1 = ctrl
trigger2 = stateno = [200,699]

;---------------------------------------------------------------------------
;Proto Charge
[State -1, Proto Shield Jab]
type = ChangeState
value = 1300
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = command = "QCF_a"
triggerall = (!var(10) && statetype = A) || Statetype != A
trigger1 = ctrl
trigger2 = stateno = [200,699]

;---------------------------------------------------------------------------
[State -1, Top Spin Jump Fierce]
type = ChangeState
value = 1202
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = (command = "QCB_c" && var(54)=0) || (command = "QCB_b" && var(54))
;triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = [200,699]

;---------------------------------------------------------------------------
[State -1, Top Spin Jump Strong]
type = ChangeState
value = 1201
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = (command = "QCB_b" && var(54)=0)
;triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = [200,699]

;---------------------------------------------------------------------------
[State -1, Top Spin Jump Jab]
type = ChangeState
value = 1200
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = command = "QCB_a"
;triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = [200,699]

;---------------------------------------------------------------------------
;Proto Blaster
[State -1, Proto Buster]
type = ChangeState
value = 1000
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = var(30) >= 75
triggerall = (!var(54) && command != "holdx" && command != "holdy" && command != "holdz" && command != "holda" && command != "holdb" && command != "holdc") || (var(54) && command != "holdx" && command != "holdy" && command != "holda" && command != "holdb")
trigger1 = ctrl
trigger2 = stateno = [200,699]
trigger3 = (stateno = [1105,1107]) && anim = 1106 && animelemtime(4) >= 0
trigger4 = (stateno = [1200,1202]) && animelemtime(8) >= 0
trigger5 = (stateno = [1300,1302]) && (anim = [1305,1306]) && animelemtime(6) >= 0

;===========================================================================
;---------------------------------------------------------------------------
;Run Back
[State -1, Dash Back]
type = ChangeState
value = 105
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = command = "BB" || (command = "holdback") && ((command = "2p" && var(54)=0) || (command = "xy" && var(54)))
triggerall = command != "holddown"
trigger1 = statetype != A || stateno = 100
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Fwd
[State -1, Dash Fwd]
type = ChangeState
value = 100
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = command = "FF" || ((command = "2p" && var(54)=0) || (command = "xy" && var(54)))
triggerall = command != "holddown"
trigger1 = statetype != A || stateno = 105
trigger1 = ctrl

;---------------------------------------------------------------------------
;Throw
[State -1, Throw]
type = ChangeState
value = 800
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = ((command = "y" || command = "z" || command = "b" || command = "c") && !var(54)) || ((command = "y" || command = "b") && var(54))
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X <= 20
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X <= 20
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H

;---------------------------------------------------------------------------
;Throw
[State -1, Throw]
type = ChangeState
value = 800
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = ((command = "y" || command = "z") && !var(54)) || ((command = "y") && var(54))
triggerall = statetype = A
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X <= 20
trigger1 = (p2statetype = A)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X <= 20
trigger2 = (p2statetype = A)
trigger2 = p2movetype != H

;===========================================================================
;---------------------------------------------------------------------------
;Taunt
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = statetype != A
triggerall = ctrl
trigger1 = command = "start"
;---------------------------------------------------------------------------
;Stand Light Punch
[State -1, Stand Jab Punch]
type = ChangeState
value = 200
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = ctrl
trigger1 = statetype = S || (stateno = [100,106])

;---------------------------------------------------------------------------
;Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = (command = "y" && var(54) = 0) || (command = "x" && var(54))
triggerall = command != "holddown"
trigger1 = ctrl
trigger1 = statetype = S || (stateno = [100,106])
trigger2 = stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430
trigger2 = movecontact

;---------------------------------------------------------------------------
[State -1, Stand Fierce Punch (Flame Sword)]
type = ChangeState
value = 220
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = (command = "z" && var(54) = 0) || (command = "y" && var(54))
triggerall = command != "holddown"
trigger1 = ctrl
trigger1 = statetype = S || (stateno = [100,106])
trigger2 = stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430 || stateno = 210 || stateno = 240 || stateno = 410 || stateno = 440
trigger2 = movecontact

;---------------------------------------------------------------------------
;Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = ctrl
trigger1 = statetype = S || (stateno = [100,106])

;---------------------------------------------------------------------------
;Standing Strong Kick
[State -1, Standing Strong Kick]
type = ChangeState
value = 240
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = (command = "b" && var(54) = 0) || (command = "a" && var(54))
triggerall = command != "holddown"
trigger1 = ctrl
trigger1 = statetype = S || (stateno = [100,106])
trigger2 = stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430
trigger2 = movecontact

;---------------------------------------------------------------------------
;Stand Strong Punch
[State -1, Stand Roundhouse Kick (Flame Sword)]
type = ChangeState
value = 250
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = (command = "c" && var(54) = 0) || (command = "b" && var(54))
triggerall = command != "holddown"
trigger1 = ctrl
trigger1 = statetype = S || (stateno = [100,106])
trigger2 = stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430 || stateno = 220 || stateno = 210 || stateno = 240 || stateno = 410 || stateno = 440
trigger2 = movecontact

;---------------------------------------------------------------------------
;Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = ctrl
trigger1 = statetype = C || (stateno = [100,106])

;---------------------------------------------------------------------------
;Crouching Strong Punch
[State -1, Crouching Strong Punch]
type = ChangeState
value = 410
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = (command = "y" && var(54) = 0) || (command = "x" && var(54))
triggerall = command = "holddown"
trigger1 = ctrl
trigger1 = statetype = C || (stateno = [100,106])
trigger2 = stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430
trigger2 = movecontact

;---------------------------------------------------------------------------
;Crouching Strong Punch
[State -1, Crouching Strong Punch]
type = ChangeState
value = 420
triggerall = (command = "z" && var(54) = 0) || (command = "y" && var(54))
triggerall = command = "holddown"
trigger1 = ctrl
trigger1 = statetype = C || (stateno = [100,106])
trigger2 = stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430 || stateno = 210 || stateno = 240 || stateno = 410 || stateno = 440
trigger2 = movecontact

;---------------------------------------------------------------------------
;Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = ctrl
trigger1 = statetype = C || (stateno = [100,106])

;---------------------------------------------------------------------------
;Crouching Strong Kick
[State -1, Crouching Strong Kick]
type = ChangeState
value = 440
triggerall = (command = "b" && var(54) = 0) || (command = "a" && var(54))
triggerall = command = "holddown"
trigger1 = ctrl
trigger1 = statetype = C || (stateno = [100,106])
trigger2 = stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430
trigger2 = movecontact

;---------------------------------------------------------------------------
;Crouching Roundhouse
[State -1, Crouching Roundhouse]
type = ChangeState
value = 450
triggerall = (command = "c" && var(54) = 0) || (command = "b" && var(54))
triggerall = command = "holddown"
trigger1 = ctrl
trigger1 = statetype = C || (stateno = [100,106])
trigger2 = stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430 || stateno = 220 || stateno = 210 || stateno = 240 || stateno = 410 || stateno = 440
trigger2 = movecontact
;---------------------------------------------------------------------------
;Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = (command = "y" && var(54) = 0) || (command = "x" && var(54))
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Fierce Punch]
type = ChangeState
value = 620
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = (command = "z" && var(54) = 0) || (command = "y" && var(54))
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 610 || stateno = 630 || stateno = 640 ;jump_x or jump_a
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 && movecontact

;---------------------------------------------------------------------------
;Jump Strong Kick
[State -1, Jump Strong Kick]
type = ChangeState
value = 640
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = (command = "b" && var(54) = 0) || (command = "a" && var(54))
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 || stateno = 610 ;jump_x or jump_a
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Fierce Kick]
type = ChangeState
value = 650
triggerall = sysvar(3) != [1,2]	 ;Not when tagged out
triggerall = (command = "c" && var(54) = 0) || (command = "b" && var(54))
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 610 || stateno = 630 || stateno = 640 || stateno = 620 ;jump_x or jump_a
trigger2 = movecontact

;----------------------------------------------------------------------------
;Full Game Commands Below, Do Not Change change only what is necessary
;----------------------------------------------------------------------------
[State -1, Super Jump Activation]
type=VarSet
triggerall = sysvar(3) != [1,4] ;not while tagged out
triggerall = StateType != A
trigger1 = command="Super_Jump"
trigger2 = movehit && Var(12) <= 1 && (stateno = 420);<-- Launcher State Here!!
trigger2 = command = "holdup"
var(11) = 3
ignorehitpause=1

[State -1, Launcher Super Jump/Jump Cancel]
type = ChangeState
triggerall = sysvar(3) != [1,4] ;not while tagged out
triggerall = roundstate = 2
trigger1 = stateno = 420	;<-- Add your LAUNCHER moves here
trigger1 = movehit = 1 && Var(12) <= 1
trigger1 = command = "holdup"
;trigger2 optional lines for manual super jump cancel
trigger2 = stateno = 220 || stateno = 250 || stateno = 450
trigger2 = command = "Super_Jump" ;Manual Input if the states included hit
trigger2 = movehit = 1
value = 40

;[State -1, Air Jump]
;type = ChangeState
;triggerall = sysvar(3) != [1,4] ;not while tagged out
;triggerall = roundstate = 2
;triggerall = Var(16) < const(data.sparkno) && Stateno != 45
;triggerall = (command="holdup") && var(19) = 1
;triggerall = !var(29) || var(29) >= 300; not during flight mode
;trigger1 = screenpos Y > const(movement.airjump.height) && Pos Y <= -const(movement.airjump.height)
;trigger1 = Statetype = A && (ctrl||(stateno = [50,51]))
;trigger2 = (stateno=600||stateno=610||stateno=620||stateno=630||stateno=635||stateno=640||stateno=645||stateno=660)&&movecontact
;value = 45

;[State -1, Wall Jump]
;type = ChangeState
;value = 70
;triggerall = var(17)=0
;triggerall = statetype=A
;triggerall = Pos Y<=-80&&Vel X!=0
;triggerall = ctrl
;trigger1 = BackEdgeBodyDist <= 10 && Vel X < 0
;trigger1 = command = "holdfwd"
;trigger2 = FrontEdgeBodyDist <= 10 && Vel X > 0
;trigger2 = command = "holdback"

;-----------------------------------------
;Advancing Guard
;-----------------------------------------
[State -1, Advance Guard Standing]
type = ChangeAnim
triggerall = stateno = 150 || stateno = 152
triggerall = selfanimexist(160) && selfanimexist(161)
triggerall = (anim != [160,161])
trigger1 = (var(54) = 0 && command = "2p") || (var(54) && command = "xy")
value = 160 + statetype = C

[State -1, Advance Crouching]
type = ChangeAnim
triggerall = stateno = 150 || stateno = 152
triggerall = selfanimexist(160) && selfanimexist(161)
triggerall = (anim != [160,161])
trigger1 = (var(54) = 0 && command = "2p") || (var(54) && command = "xy")
value = 160 + statetype = C

[State -1, Advance Guard Air]
type = ChangeAnim
triggerall = stateno = 154
triggerall = selfanimexist(162)
triggerall = (anim != 162)
trigger1 = (var(54) = 0 && command = "2p") || (var(54) && command = "xy")
value = 162

[State -1, PosFreeze] ;Freeze position during advancing guard
type = PosFreeze
trigger1 = (anim = [160,162])&&(stateno=[150,155])
value = 1
ignorehitpause = 1

[State -1, Advance Guard];Advancing Guard Push Helper
type = Helper
triggerall = (stateno = [150,159])
trigger1 = (anim = [160,162])
trigger1 = animelem=2
helpertype = Normal
name = "Advance Guard"
postype = P1
pos = 0,0
stateno = 8310
ownpal = 0
size.height = 240

;----------------------------------------------------------------
;Tech Hit Recovery Roll
[State -1, Tech Recovery Forward Trigger]
type = VarSet
triggerall = sysvar(3) != [1,4]
triggerall = var(7) != -1
triggerall = (command = "counter1" && var(54) = 0) || ((command = "recoverf1" || command = "recoverf2") && var(54));command = "recoverf1" || command = "recoverf2" || command = "recoverf3"
triggerall = (GetHitVar(chainID) != [5115,5159]) && (GetHitVar(chainID) != [5063,5064])
triggerall = alive && hitfall
trigger1 = (movetype = H) && statetype = A
trigger1 = vel y >= 0 && pos y >= floor(-vel y) - 30
trigger2 = (statetype = L && time <= 2)
var(7) = 1

[State -1, Tech Recovery Back Trigger]
type = VarSet
triggerall = sysvar(3) != [1,4]
triggerall = var(7) != -1
triggerall = (command = "counter2" && var(54) = 0)|| ((command = "recoverb1" || command = "recoverb2") && var(54));command = "recoverb1" || command = "recoverb2" || command = "recoverb3"
triggerall = (GetHitVar(chainID) != [5115,5159]) && (GetHitVar(chainID) != [5063,5064])
triggerall = alive && hitfall
trigger1 = (movetype = H) && statetype = A
trigger1 = vel y >= 0 && pos y >= floor(-vel y) - 30
trigger2 = (statetype = L && time <= 2)
var(7) = 2

[State -1, Locked Out by Missed Tech]
type = VarSet
triggerall = sysvar(3) != [1,4]
triggerall = (command = "counter1" && var(54) = 0) || ((command = "recoverf1" || command = "recoverf2") && var(54)) || (command = "counter2" && var(54) = 0)|| ((command = "recoverb1" || command = "recoverb2") && var(54))
;triggerall = command = "recoverf1" || command = "recoverf2" || command = "recoverf3" || command = "recoverb1" || command = "recoverb2" || command = "recoverb3"
triggerall = alive && hitfall
triggerall = (GetHitVar(chainID) != [5115,5159]) && (GetHitVar(chainID) != [5063,5064])
trigger1 = movetype = H && statetype = A && (vel y < 0 || pos y < floor(-vel y) - 30)
trigger2 = (statetype = L && time > 2)
var(7) = -1

[State -1, Tech Recovery Var Normal Reset]
type = VarSet
triggerall = sysvar(3) != [1,4]
triggerall = var(7) > 0
trigger1 = (stateno = [5220,5221])
trigger2 = movetype = H && !hitshakeover && (stateno != [120,159])
trigger3 = movetype != H && (stateno != [120,159])
var(7) = 0

[State -1, Tech Recovery Var Lock Out Reset]
type = VarSet
triggerall = sysvar(3) != [1,4]
triggerall = var(7) < 0
trigger1 = movetype != H && (stateno != [120,159])
var(7) = 0

[State -1, Tech Recovery ChangeState]
type = ChangeState
triggerall = sysvar(3) != [1,4]
triggerall = (var(7) = [1,2])
triggerall = alive 
trigger1 = (stateno = 5100 || stateno = 5102 || stateno = 5110 || stateno = 5115 || stateno = 5107 || (stateno = [5106,5108]) && vel y > 0 && Pos Y >= Const(movement.down.bounce.groundlevel)) && time > 0
value = 5220